package com.hw.mes.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import com.hw.mes.domain.vo.MesProductPlanDetailVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.mes.mapper.MesProductPlanDetailMapper;
import com.hw.mes.domain.MesProductPlanDetail;
import com.hw.mes.service.IMesProductPlanDetailService;

/**
 * 生产计划明细Service业务层处理
 *
 * @author xins
 * @date 2024-02-21
 */
@Service
public class MesProductPlanDetailServiceImpl implements IMesProductPlanDetailService
{
    @Autowired
    private MesProductPlanDetailMapper mesProductPlanDetailMapper;

    /**
     * 查询生产计划明细
     *
     * @param planDetailId 生产计划明细主键
     * @return 生产计划明细
     */
    @Override
    public MesProductPlanDetail selectMesProductPlanDetailByPlanDetailId(Long planDetailId)
    {
        return mesProductPlanDetailMapper.selectMesProductPlanDetailByPlanDetailId(planDetailId);
    }

    /**
     * 查询生产计划明细列表
     *
     * @param mesProductPlanDetail 生产计划明细
     * @return 生产计划明细
     */
    @Override
    public List<MesProductPlanDetail> selectMesProductPlanDetailList(MesProductPlanDetail mesProductPlanDetail)
    {
        return mesProductPlanDetailMapper.selectMesProductPlanDetailList(mesProductPlanDetail);
    }

    /**
     * 新增生产计划明细
     *
     * @param mesProductPlanDetail 生产计划明细
     * @return 结果
     */
    @Override
    public int insertMesProductPlanDetail(MesProductPlanDetail mesProductPlanDetail)
    {
        mesProductPlanDetail.setCreateTime(DateUtils.getNowDate());
        return mesProductPlanDetailMapper.insertMesProductPlanDetail(mesProductPlanDetail);
    }

    /**
     * 修改生产计划明细
     *
     * @param mesProductPlanDetail 生产计划明细
     * @return 结果
     */
    @Override
    public int updateMesProductPlanDetail(MesProductPlanDetail mesProductPlanDetail)
    {
        mesProductPlanDetail.setUpdateTime(DateUtils.getNowDate());
        return mesProductPlanDetailMapper.updateMesProductPlanDetail(mesProductPlanDetail);
    }

    /**
     * 批量删除生产计划明细
     *
     * @param planDetailIds 需要删除的生产计划明细主键
     * @return 结果
     */
    @Override
    public int deleteMesProductPlanDetailByPlanDetailIds(Long[] planDetailIds)
    {
        return mesProductPlanDetailMapper.deleteMesProductPlanDetailByPlanDetailIds(planDetailIds);
    }

    /**
     * 删除生产计划明细信息
     *
     * @param planDetailId 生产计划明细主键
     * @return 结果
     */
    @Override
    public int deleteMesProductPlanDetailByPlanDetailId(Long planDetailId)
    {
        return mesProductPlanDetailMapper.deleteMesProductPlanDetailByPlanDetailId(planDetailId);
    }




    /**
     * 根据生产计划新增生产计划明细
     *
     * @param mesProductPlanDetailVo 生产计划明细Vo
     * @return 结果
     */
    @Override
    public int insertMesProductPlanDetails(MesProductPlanDetailVo mesProductPlanDetailVo)
    {
//        mesProductPlanDetail.setCreateTime(DateUtils.getNowDate());
//        return mesProductPlanDetailMapper.insertMesProductPlanDetail(mesProductPlanDetail);
//        MesProductPlan mesProductPlan
        return 1;
    }

}
