package com.hw.mes.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import com.hw.common.security.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import com.hw.common.core.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;
import com.hw.mes.domain.MesProductPlanDetail;
import com.hw.mes.mapper.MesProductPlanMapper;
import com.hw.mes.domain.MesProductPlan;
import com.hw.mes.service.IMesProductPlanService;

/**
 * 生产派工Service业务层处理
 *
 * @author xins
 * @date 2024-02-21
 */
@Service
public class MesProductPlanServiceImpl implements IMesProductPlanService
{
    @Autowired
    private MesProductPlanMapper mesProductPlanMapper;

    /**
     * 查询生产派工
     *
     * @param planId 生产派工主键
     * @return 生产派工
     */
    @Override
    public MesProductPlan selectMesProductPlanByPlanId(Long planId)
    {
        return mesProductPlanMapper.selectMesProductPlanByPlanId(planId);
    }

    /**
     * 查询生产派工列表
     *
     * @param mesProductPlan 生产派工
     * @return 生产派工
     */
    @Override
    public List<MesProductPlan> selectMesProductPlanList(MesProductPlan mesProductPlan)
    {
        return mesProductPlanMapper.selectMesProductPlanList(mesProductPlan);
    }

    /**
     * 新增生产派工
     *
     * @param mesProductPlan 生产派工
     * @return 结果
     */
    @Transactional
    @Override
    public int insertMesProductPlan(MesProductPlan mesProductPlan)
    {
        mesProductPlan.setCreateTime(DateUtils.getNowDate());
        int rows = mesProductPlanMapper.insertMesProductPlan(mesProductPlan);
        insertMesProductPlanDetail(mesProductPlan);
        return rows;
    }

    /**
     * 修改生产派工
     *
     * @param mesProductPlan 生产派工
     * @return 结果
     */
    @Transactional
    @Override
    public int updateMesProductPlan(MesProductPlan mesProductPlan)
    {
        mesProductPlan.setUpdateTime(DateUtils.getNowDate());
        mesProductPlanMapper.deleteMesProductPlanDetailByPlanId(mesProductPlan.getPlanId());
        insertMesProductPlanDetail(mesProductPlan);
        return mesProductPlanMapper.updateMesProductPlan(mesProductPlan);
    }

    /**
     * 批量删除生产派工
     *
     * @param planIds 需要删除的生产派工主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteMesProductPlanByPlanIds(Long[] planIds)
    {
        mesProductPlanMapper.deleteMesProductPlanDetailByPlanIds(planIds);
        return mesProductPlanMapper.deleteMesProductPlanByPlanIds(planIds);
    }

    /**
     * 删除生产派工信息
     *
     * @param planId 生产派工主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteMesProductPlanByPlanId(Long planId)
    {
        mesProductPlanMapper.deleteMesProductPlanDetailByPlanId(planId);
        return mesProductPlanMapper.deleteMesProductPlanByPlanId(planId);
    }

    /**
     * 新增生产计划明细信息
     *
     * @param mesProductPlan 生产派工对象
     */
    public void insertMesProductPlanDetail(MesProductPlan mesProductPlan)
    {
        List<MesProductPlanDetail> mesProductPlanDetailList = mesProductPlan.getMesProductPlanDetailList();
        Long planId = mesProductPlan.getPlanId();
        if (StringUtils.isNotNull(mesProductPlanDetailList))
        {
            List<MesProductPlanDetail> list = new ArrayList<MesProductPlanDetail>();
            for (MesProductPlanDetail mesProductPlanDetail : mesProductPlanDetailList)
            {
                mesProductPlanDetail.setPlanId(planId);
                list.add(mesProductPlanDetail);
            }
            if (list.size() > 0)
            {
                mesProductPlanMapper.batchMesProductPlanDetail(list);
            }
        }
    }







    /**
     * 查询生产派工列表Join product_order和base_material
     *
     * @param mesProductPlan 生产派工
     * @return 生产派工
     */
    @Override
    public List<MesProductPlan> selectMesProductPlanJoinList(MesProductPlan mesProductPlan)
    {
        Long stationId = SecurityUtils.getStationd();
        System.out.println("stationId: " + stationId);
        return mesProductPlanMapper.selectMesProductPlanJoinList(mesProductPlan);
    }

}
